//force default legacy door support
%error = ForceRequiredAddOn("Support_LegacyDoors");
if(%error == $Error::AddOn_NotFound)
{
	error("Support_LegacyDoorsExpanded: Support_LegacyDoors is missing somehow, what did you do?");
	return;
}

if($Pref::Server::LegacyDoorsExpanded::ClassicDoorSounds $= "") //uses classic door sound for door bricks placed from when it was enabled
	$Pref::Server::LegacyDoorsExpanded::ClassicDoorSounds = false;

if($Pref::Server::LegacyDoorsExpanded::DisableDoorSounds $= "") //restoration of $disableJVSSounds, disables adding door sounds to legacy doors
	$Pref::Server::LegacyDoorsExpanded::DisableDoorSounds = false;

if($Pref::Server::LegacyDoorsExpanded::CheckUiNames $= "") //allows the script to change subcategorisation of specific doors by checking their ui name
	$Pref::Server::LegacyDoorsExpanded::CheckUiNames = true;

if($Pref::Server::LegacyDoorsExpanded::UseOwnCategory $= "") //moves all legacy doors to their own tab in the brick selector, like what jvs did.
	$Pref::Server::LegacyDoorsExpanded::UseOwnCategory = false;

//RTB Prefs
if($RTB::Hooks::ServerControl)
{
	RTB_registerPref("Give doors classic AIM door sounds when placed",			"Legacy Doors Expanded",	"$Pref::Server::LegacyDoorsExpanded::ClassicDoorSounds",	"bool",	"Support_LegacyDoorsExpanded",	false,	false,	false,	false);
	RTB_registerPref("Don't give doors sounds when placed",						"Legacy Doors Expanded",	"$Pref::Server::LegacyDoorsExpanded::DisableDoorSounds",	"bool",	"Support_LegacyDoorsExpanded",	false,	false,	false,	false);
	RTB_registerPref("Check UI names of doors to determine their subcategory",	"Legacy Doors Expanded",	"$Pref::Server::LegacyDoorsExpanded::CheckUiNames",			"bool",	"Support_LegacyDoorsExpanded",	true,	true,	false,	false);
	RTB_registerPref("Put all legacy doors into their own category",			"Legacy Doors Expanded",	"$Pref::Server::LegacyDoorsExpanded::UseOwnCategory",		"bool",	"Support_LegacyDoorsExpanded",	false,	true,	false,	false);
}
	
//reimplementation of original door sounds
datablock AudioProfile(contentSoundStartAIM)
{
	filename = "Add-Ons/Support_LegacyDoorsExpanded/doorClassicOpen.wav";
	description = AudioClose3d;
	preload = true;
};
datablock AudioProfile(contentSoundStopAIM)
{
	filename = "Add-Ons/Support_LegacyDoorsExpanded/doorClassicClose.wav";
	description = AudioClose3d;
	preload = true;
};

//reimplementation of original error sound - for use in events
datablock AudioProfile(contentError)
{
	filename = "Add-Ons/Support_LegacyDoorsExpanded/doorClassicError.wav";
	description = AudioClose3d;
	preload = true;
};

package legacyDoorsExpandedPackage
{
	function fxDTSBrick::onPlant(%this)
	{
		$disableJVSSounds = $Pref::Server::LegacyDoorsExpanded::DisableDoorSounds; //$disableJVSSounds was left doing nothing in the default scripts. this simply adds a way for normal players to use it.
		parent::onPlant(%this);
		if(!$Pref::Server::LegacyDoorsExpanded::ClassicDoorSounds)
			return;
		
		%data = %this.getDataBlock();
		if(!$disableJVSSounds && %data.isJVS &&  isObject(%data.datablockSoundStart) && isObject(%data.datablockSoundStop)) //check if it's a legacy door, then apply the classic sounds.
		{
			if(%data.datablockSoundStart.getID() == contentSoundStartLegacyDoor.getID())
				%this.eventOutputParameter1_1 = contentSoundStartAIM.getID();
			if(%data.datablockSoundStop.getID() == contentSoundStopLegacyDoor.getID())
			{
				%this.eventDelay2 = "600";
				%this.eventOutputParameter2_1 = contentSoundStopAIM.getID();
			}
		}
	}
	
	function ContentTypesSO::addContentType(%this, %file)
	{
		parent::addContentType(%this, %file);
		
		%fileRead = new FileObject();
		if(%fileRead.openForRead(%file)) //we have to find the name of the brick's datablock, there's no other way to do this as far as i can tell
		{ //we're simply copying what was done in the file reading part of applyJVSVariables, but skipping everything that isnt datablockBrick and grabbing only the value
			while(!%fileRead.isEOF())
			{
				%line = %fileRead.readLine();
				%length = strlen(%line);
				if(%length < 21 || strstr(%line, "$") == -1)
					continue;
				
				//if we detect a comment continue
				if(strstr(%line, "//") == 0)
					continue;
				
				//if we detect a comment after the variable remake the line
				%commentCheck = strstr(%line, "//");
				if(%commentCheck > 30)
					%line = getSubStr(%line, 0, %commentCheck);
				
				//continue if we dont find datablockBrick
				if(strstr(%line, "datablockBrick") == -1)
					continue;
				
				//strip it down
				%line = getSubStr(%line, 39, 128);
				%line = strReplace(%line, "\";", "");
				
				%data = %line; //we got the datablock
			}
		}
		%fileRead.close();
		%fileRead.delete();
		
		if(!isObject(%data)) //make sure it actually is a datablock
		{
			error("couldnt find datablockBrick \"" @ %data @ "\" in door file " @ %file);
			return;
		}
		
		if($Pref::Server::LegacyDoorsExpanded::UseOwnCategory)
			%data.category = "Legacy Doors";
		
		%subCat = strlwr(%data.brickSubcategory); //we're redoing the subcategory names, to support more content types.
		if(strstr(%subCat, "switch") >= 0)
			%data.subCategory = "Legacy Switches";
		else if(strstr(%subCat, "kyle") >= 0) //it seems kyle categorised their stuff only under their name, luckily they only made switches.
			%data.subCategory = "Legacy Switches";
		else if(strstr(%subCat, "trap") >= 0)
			%data.subCategory = "Legacy Traps";
		else
			%data.subCategory = "Legacy Doors";
		
		if($Pref::Server::LegacyDoorsExpanded::CheckUiNames)
		{
			//we'll also do some mostly hardcoded subcategory edits, to the point of basically patching them without editing the original files. we're checking their ui names and changing their subcategory based on that.
			%uiName = strlwr(%data.uiName);
			if(strstr(%uiName, "fan") >= 0) //should cover all fans
				%data.subCategory = "Legacy Traps";
			if(strstr(%uiName, "window") >= 0) //should cover all windows
				%data.subCategory = "Legacy Misc";
			else if(%uiName $= "circular grate")
				%data.subCategory = "Legacy Misc";
			else if(%uiName $= "manhole cover")
				%data.subCategory = "Legacy Misc";
			else if(%uiName $= "hatch")
				%data.subCategory = "Legacy Misc";
			else if(%uiName $= "trap door")
				%data.subCategory = "Legacy Traps";
			else if(%uiName $= "air vent")
				%data.subCategory = "Legacy Misc";
		}
		
		%shape = %data.datablockShape;
		%data.datablockGhostShape = %shape;
		%shapeColliding = %data.datablockShapeColliding;
		if(%shape $= %shapeColliding)
			return;
		
		%filePath = filePath(%file);
		%basePath = getSubStr(%filePath, 0, strLen(%filePath) - 5);
		%shapeFile = %basePath @ "shapes/" @ %shape @ ".dts";
		datablock StaticShapeData(contentShapeGhost)
		{
			shapefile = %shapeFile;
		};
		contentShapeGhost.setName(%shape @ "Ghost");
		%data.datablockGhostShape = %shape @ "Ghost";
	}
	
	function fxDTSBrick::contentGhostBrickCheck( %obj ) //complete copy and overwrite of the function just to use collisionless shape smh
	{
		// check if we exist and we're not planted	
		if( !isObject( %obj ) || %obj.isPlanted )
			return;
		
		%data = %obj.getDataBlock();
		
		%client = %obj.getGroup().client;
		
		// if we're not a door datablock then return
		if( !%data.isJVS )
		{
			// check if we have a ghost shape somehow
			if( isObject( %obj.ghostShape ) )
			{
				%obj.ghostShape.delete();
				%client.ghostShape = "";
			}
			
			return;
		}
		
		// get position and rotation
		%pos = %obj.position;
		%angleID = %obj.getAngleID();
		
		// if we don't have a ghost shape create it, if we do have one but it doesn't match our current shape switch it
		if( !isObject( %obj.ghostShape ) )
		{
			%dataBlock = %data.datablockGhostShape;//ContentTypesSO.getDatablockShapeFromID(%contentTypeID);

			%obj.ghostShape = new StaticShape()
			{
				dataBlock = %dataBlock;
			};
			
			missionCleanup.add( %obj.ghostShape );
		}
		else if( isObject( %obj.ghostShape ) && %obj.ghostShape.getDataBlock().getName() !$= %data.datablockGhostShape )
			%obj.ghostShape.setDataBlock( %data.datablockGhostShape );
		
		%client.ghostShape = %obj.ghostShape;
		
		// paint the ghost shape // moved to contentColor function
		%obj.contentColor();
		
		// handle rotation
		if(%angleID == 2)
			%rot = eulerToQuat("0 0 270");
		else if(%angleID == 3)
			%rot = eulerToQuat("0 0 180");
		else if(%angleID == 0)
			%rot = eulerToQuat("0 0 90");
		else
			%rot = eulerToQuat("0 0 0");

		%obj.ghostShape.setTransform( %pos SPC %rot );
		
		return;
	}
};
activatePackage(legacyDoorsExpandedPackage);